Learn R Programming

vacalibration (version 2.0)

comsamoz_public_broad: COMSA-Mozambique: Example Individual-Level Broad Cause of Death Data (Publicly Available Version)

Description

Example individual‑level neonatal cause‑of‑death data using InSilicoVA. This is obtained after broad cause mapping of comsamoz_public_openVAout$data using cause_map() function in this package.

Usage

comsamoz_public_broad

Arguments

Format

A list of 4 components.

data

Binary matrix. Contains the data. Rows are individuals. Columns are broad causes. Matrix elements are 0 or 1, with 1 indicating the cause of death for an individual.

age_group

Character. Indicate age group. "neonate" (for 0-27 days) for this data

va_algo

Character. Indicate CCVA algorithm. "insilicova" for this data

version

Character. Date stamp for version control of tracking updates. Only for package maintainers.

Details

This shows how individual level broad cause of death data can be an input in the vacalibration() function for calibration.

comsamoz_public_broad$data[i,j] is a binary indicator of whether broad cause j is the cause of death for individual i. 1 indicates it is, and 0 indicates it is not.

Broad causes for "neonate" are

  • "congenital_malformation",

  • "pneumonia",

  • "sepsis_meningitis_inf" (sepsis/meningitis/infections),

  • "ipre" (intrapartum-related events),

  • "other", and

  • "prematurity".

For "child", the broad causes are

  • "malaria",

  • "pneumonia",

  • "diarrhea",

  • "severe_malnutrition",

  • "hiv",

  • "injury",

  • "other",

  • "other_infections", and

  • "nn_causes" (neonatal causes; consists of IPRE, congenital malformation, and prematurity).

References

Macicame, I, et al. (2023). Countrywide Mortality Surveillance for Action in Mozambique: Results from a National Sample-Based Vital Statistics System for Mortality and Cause of Death. American Journal of Tropical Medicine and Hygiene, 108(Suppl 5), pp. 5–16.

Examples

Run this code

# \donttest{

## using the data
data(comsamoz_public_broad)
head(comsamoz_public_broad$data)  # head of the data
comsamoz_public_broad$data[1,]  # binary vector indicating cause of death for individual 1

## mapped to national death counts
comsamoz_public_asdeathcount = colSums(comsamoz_public_broad$data)

## VA-calibration for the "neonate" age group and InSilicoVA algorithm
## input as broad cause
calib_out_asbroad = vacalibration(va_data = setNames(list(comsamoz_public_broad$data),
                                                     list(comsamoz_public_broad$va_algo)),
                                     age_group = comsamoz_public_broad$age_group,
                                     country = "Mozambique")

## input as specific cause
calib_out_asdeathcount = vacalibration(va_data = setNames(list(comsamoz_public_asdeathcount),
                                                          list(comsamoz_public_broad$va_algo)),
                                       age_group = comsamoz_public_broad$age_group,
                                       country = "Mozambique")

## comparing uncalibrated CSMF estimates and posterior summary of calibrated CSMF estimates
## all are the same
calib_out_asbroad$p_uncalib
calib_out_asbroad$pcalib_postsumm[1,,]

calib_out_asdeathcount$p_uncalib
calib_out_asdeathcount$pcalib_postsumm[1,,]

# }

Run the code above in your browser using DataLab